<?php
namespace MINAV\Layersliderlight\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013
 *  Manfred Rutschmann <rutschmann@agentur-volumen.de>, VOLUMEN Werbe-/Internetagentur
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package layersliderlight
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class SlideController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * slideRepository
	 *
	 * @var \MINAV\Layersliderlight\Domain\Repository\SlideRepository
	 * @inject
	 */
	protected $slideRepository;

	/**
	 * action list
	 *
	 * @return void
	 */
	public function listAction() {
		$slides = $this->slideRepository->findAll();
		$this->view->assign('slides', $slides);
	}

	/**
	 * action show
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slide $slide
	 * @return void
	 */
	public function showAction(\MINAV\Layersliderlight\Domain\Model\Slide $slide) {
		$this->view->assign('slide', $slide);
	}

	/**
	 * action new
	 *
     * @param \MINAV\Layersliderlight\Domain\Model\Slider $slider
     * @param \MINAV\Layersliderlight\Domain\Model\Slide $newSlide
     * @dontvalidate $newSlide
	 * @return void
	 */
	public function newAction(\MINAV\Layersliderlight\Domain\Model\Slider $slider, \MINAV\Layersliderlight\Domain\Model\Slide $newSlide = NULL) {
	    if($newSlide === NULL){
            $newSlide = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("MINAV\\Layersliderlight\\Domain\\Model\\Slide");
            /* var $newSlide MINAV\\Layersliderlight\\Domain\\Model\\Slide  */
            $newSlide->setTitle("New Slide");
            $newSlide->setSlider($slider);
            $newSlide->setSorting(99999);
	    }
        $this->forward("create", NULL, NULL, array("newSlide" => $newSlide));
	}

	/**
	 * action create
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slide $newSlide
	 * @return void
	 */
	public function createAction(\MINAV\Layersliderlight\Domain\Model\Slide $newSlide) {

		$this->slideRepository->add($newSlide);
        $persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
        $persistenceManager->persistAll();
        $this->forward("edit", NULL, NULL, array("slide" => $newSlide));
	}

	/**
	 * action edit
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slide $slide
	 * @return void
	 */
	public function editAction(\MINAV\Layersliderlight\Domain\Model\Slide $slide) {
		$this->view->assign('slide', $slide);
        return $this->view->render();
	}

	/**
	 * action update
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slide $slide
	 * @return void
	 */
	public function updateAction(\MINAV\Layersliderlight\Domain\Model\Slide $slide) {
		$this->slideRepository->update($slide);
		$this->flashMessageContainer->add('Your Slide was updated.');
		$this->redirect('list');
	}

	/**
	 * action delete
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slide $slide
	 * @return void
	 */
	public function deleteAction(\MINAV\Layersliderlight\Domain\Model\Slide $slide) {
		$this->slideRepository->remove($slide);
		$this->flashMessageContainer->add('Your Slide was removed.');

        $image = \TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName('uploads/tx_layersliderlight/'.$slide->getImage());

        if($image){
            @unlink($image);
        }

	}

    /**
     *
     * @return void
     */
    public function uploadAction(){
        $request = $this->request->getArguments();
        $returnArray = array();
        if($request['file']['name'] && $request['slide']){
            $allowed = array('jpg','png','gif');

            if(  in_array( pathinfo($request['file']['name'], PATHINFO_EXTENSION), $allowed ) ) {

                $slide = $this->slideRepository->findByUid($request['slide']);
                /* @var $slide \MINAV\Layersliderlight\Domain\Model\Slide  */
                $returnArray['item_uid'] = $slide->getUid();

                $basicFileFunctions = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Core\\Utility\\File\\BasicFileUtility');
                /* @var $basicFileFunctions \TYPO3\CMS\Core\Utility\File\BasicFileUtility  */

                $oldImage = \TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName('uploads/tx_layersliderlight/'.$slide->getImage());

                if($oldImage){
                    @unlink($oldImage);
                    $returnArray['oldimage_deleted'] = true;
                }

                $filename = $basicFileFunctions->getUniqueName(
                    $request['file']['name'],
                    \TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName('uploads/tx_layersliderlight/')
                );

                $uploaded = \TYPO3\CMS\Core\Utility\GeneralUtility::upload_copy_move(
                    $request['file']['tmp_name'],
                    $filename
                );
                if($uploaded === TRUE){
                    $returnArray['message'] = 'Fileupload successful';
                } else {
                    $returnArray['message'] = 'Upload failed... i have no idea what you are doing! Try again ;-)';
                }
                $returnArray['pathinfo'] = pathinfo($filename);
                $returnArray['uploaded'] = $uploaded;


                $slide->setImage(\basename($filename));
                $this->slideRepository->update($slide);
            } else {
                $returnArray['uploaded'] = false;
                $returnArray['message'] = 'Please use only jpg, png or gif image files!';
            }


        }
        $this->response->setHeader('Content-Type', 'application/json', TRUE);
        $this->view->assign('json', json_encode($returnArray));

    }


}
?>