<?php
namespace MINAV\Layersliderlight\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013
 *  Manfred Rutschmann <rutschmann@agentur-volumen.de>, VOLUMEN Werbe-/Internetagentur
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
use TYPO3\CMS\Extbase\Utility\DebuggerUtility;

/**
 *
 *
 * @package layersliderlight
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class SliderController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * sliderRepository
	 *
	 * @var \MINAV\Layersliderlight\Domain\Repository\SliderRepository
	 * @inject
	 */
	protected $sliderRepository;

    /**
     * slideRepository
     *
     * @var \MINAV\Layersliderlight\Domain\Repository\SlideRepository
     * @inject
     */
    protected $slideRepository;


    /**
	 * action list
	 *
	 * @return void
	 */
	public function listAction() {
        if($this->settings['tsIncluded']!=1){
            echo '<p>You forgot to include the static extension template in the root template!</p>';
            return false;
        } else {

            $frameworkConfiguration = $this->configurationManager->getConfiguration(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface::CONFIGURATION_TYPE_FRAMEWORK);
            $sliders = $this->sliderRepository->findAllBe($frameworkConfiguration['persistence']['storagePid']);
            $this->view->assign('sliders', $sliders);
        }
	}

	/**
	 * action show
	 *
	 * @return void
	 */
	public function showAction() {

        if($this->settings['slider'] > 0){
            $slider = $this->sliderRepository->findByUid((int)$this->settings['slider']);
            $options = $slider->getOptions();
            if(strlen($options['skinsPath']) > 1){
                $explodedPath = explode("/", $options['skinsPath']);
                $newSkin = $explodedPath[count($explodedPath) - 1];
                $lastPosition = strripos($options['skinsPath'], "/");
                $newSkinsPath = ltrim(substr($options['skinsPath'], 0, $lastPosition)."/", "/");
                $options['skinsPath'] = $newSkinsPath;
                $options['skin'] = $newSkin;
//                DebuggerUtility::var_dump($options);
                $slider->setOptions(json_encode($options));
            }
            $this->view->assign( 'slider',  $slider);
        }
        $this->view->assign( 'slider',  $slider)->assign('tsincluded', $this->settings['tsIncluded']);
    }

	/**
	 * action new
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slider $newSlider
	 * @dontvalidate $newSlider
	 * @return void
	 */
	public function newAction(\MINAV\Layersliderlight\Domain\Model\Slider $newSlider = NULL) {
		$this->view->assign('newSlider', $newSlider);
	}

	/**
	 * action create
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slider $newSlider
	 * @return void
	 */
	public function createAction(\MINAV\Layersliderlight\Domain\Model\Slider $newSlider) {
		$this->sliderRepository->add($newSlider);
        $persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
        $persistenceManager->persistAll();
		$this->flashMessageContainer->add('Your new Slider was created.');
		$this->redirect('edit', NULL, NULL, array("slider" => $newSlider));
	}

	/**
	 * action edit
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slider $slider
	 * @return void
	 */
	public function editAction(\MINAV\Layersliderlight\Domain\Model\Slider $slider) {

        $options = $slider->getOptions();
        if(strlen($options['skinsPath']) > 1){
            $explodedPath = explode("/", $options['skinsPath']);
            $newSkin = $explodedPath[count($explodedPath) - 1];
            $lastPosition = strripos($options['skinsPath'], "/");
            $newSkinsPath = "/".ltrim(substr($options['skinsPath'], 0, $lastPosition)."/", "/");
            $options['skinsPath'] = $newSkinsPath;
            $options['skin'] = $newSkin;
        }
        $this->view->assign( 'slider',  $slider)->assign('options', $options);
	}


     /**
     * Initializes the current action
     * @return void
     */
    public function initializeUpdateAction() {
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($sliderFormData);
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($this->request->getArguments());
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($this->arguments);
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($_POST);
        if (isset($this->arguments['slider'])) {
            $this->arguments['slider']->getPropertyMappingConfiguration()->allowProperties('formslides');
            $this->arguments['slider']->getPropertyMappingConfiguration()->allowProperties('formitems');
            $this->arguments['slider']->getPropertyMappingConfiguration()->forProperty('options')->setTypeConverterOption('MINAV\\LAYERSLIDER\\Property\\TypeConverter\\ArrayConverter', array(), array());
        }
    }


 
 
	/**
	 * action update
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slider $slider
	 * @return void
	 */
	public function updateAction(\MINAV\Layersliderlight\Domain\Model\Slider $slider) {

        $sliderFormData = $slider->getFormslides();
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($sliderFormData);
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($this->request->getArguments());
//        \TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($_POST);
//        exit;
        if(is_array($sliderFormData)){
            $i = 0;
            foreach ($sliderFormData as $fsKey => $fsVal) {
                // handle the slides
                $existingSlide = $this->slideRepository->findByUid($fsKey);
                /* @var \MINAV\Layersliderlight\Domain\Model\Slide $existingSlide  */
                if($existingSlide instanceof \MINAV\Layersliderlight\Domain\Model\Slide){
                    $existingSlide->setTitle($fsVal['title']);
                    $existingSlide->setSorting($i);
                    $existingSlide->setConfiguration( $fsVal['configuration'] );
                    $this->slideRepository->update($existingSlide);
                }

                $i++;
            }
        }
		$this->sliderRepository->update($slider);
        $persistenceManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance("TYPO3\\CMS\\Extbase\\Persistence\\Generic\\PersistenceManager");
        $persistenceManager->persistAll();
        $this->flashMessageContainer->add('Your Slider was updated.');
        $this->redirect('edit', NULL, NULL, array("slider" => $slider));
	}

	/**
	 * action delete
	 *
	 * @param \MINAV\Layersliderlight\Domain\Model\Slider $slider
	 * @return void
	 */
	public function deleteAction(\MINAV\Layersliderlight\Domain\Model\Slider $slider) {
		$this->sliderRepository->remove($slider);
		$this->flashMessageContainer->add('Your Slider was removed.');
		$this->redirect('list');
	}

}
?>